<?php
/*
 * ============================================================================
 * Licensed Materials - Property of IBM
 *  WebSphere sMash
 *
 * (C) Copyright IBM Corp. 2007  All Rights Reserved.
 *
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 * ============================================================================
 */

include 'restutils.php';

class BlueGroup {
	var $MAX_MEMBERS_IN_GROUP = 75;
	
	/**
	 * Retreive bluegroup members
     * @success 200 Returns the members of the specified bluegroup
     * @format text/html
     */
	function onRetrieve() {
		$groupName = zget('/request/params/bluegroupId');
		$bluegroupsurl = zget('/config/external/groups/url').$groupName;
		$response = connection_get($bluegroupsurl, array());
		$group = xml_decode($response['body']);
		$teamName = $group->groupName[0]->toString();
		echo "Create team with team name:". $teamName;
		foreach ($group->member as $member) {
			// Add member to community
			echo "Adding member ". $member->toString() ." to community.";
			echo "Add member ". $member->toString(). " to team ". $teamName;
		}
	}
	
	/**
	 * Create Users and team (if specified) to reflect the bluegroup specified
	 * @success 200 Creates the members and team as specified based on bluegroup membership
	 * @error 400 If there are more than 75 members in the bluegroup
	 *
	 */
	function onCreate() {
		$result = false;
		$defaultOrg = 'Zero';
        $dm = data_manager('hallmondb');
		$errorResponse = "Problem with data/application.";
        $groupInfo = json_decode($HTTP_RAW_POST_DATA);
        if (!zcontains('/config/external/groups/url')) {
        	zput('/request/status', 400);
        	echo "Group URL not configured";
        	return;
        }
        $bluegroupsurl = zget('/config/external/groups/url').$groupInfo['name'];
   	    $response = connection_get($bluegroupsurl, array());
       	$group = xml_decode($response['body']);
   	 	$rc = $group->rc[0]->toString();
       	if ($rc != 0) {
       		$errorResponse .= $group->msg[0].toString();
        } else if (count($group->member) > $this->MAX_MEMBERS_IN_GROUP) {
        	$errorResponse .= 'Too many members in group ('.count($group->member).').';
        } else {
        	// check if team already exists ??
        	$addToTeam = false;
            if (isset($groupInfo['createteam'])) {
               	$result = data_exec($dm, 'INSERT INTO teams (name, description, orgname)'.
                     'VALUES (?, ?, ?)', 
                     array($groupInfo['name'], $groupInfo['name'], $defaultOrg));
                $addToTeam = true;
            }
            // Add members ... etc
            
            $newMembers = array();
            foreach ($group->member as $member) {
            	$email = $member->toString();
                // First check if member is already in community
            	$person = data_query_first($dm, "SELECT * FROM people WHERE email = ?", array($email));
                if (!isset($person)) {
                    // build up member information; need each member's name
                    $memberDetailUrl = zget('/config/external/person/detailurl').$email;
                    $response = connection_get($memberDetailUrl, array());
                    $properties = property_decode($response['body']);
                    $name = $properties['HRFIRSTNAME'].' '.$properties['HRLASTNAME'];
                    $phone = $properties['XPHONE'];
                    // Add to community
                    $result = data_exec($dm, 'INSERT INTO people (name, email, home_phone)'.
                        'VALUES (?, ?, ?)', 
                        array($name, $email, $phone));
                }                       
                // Add to team ?
                if ($addToTeam) {
                	$updates = data_exec($dm, "INSERT INTO teammembers (name, member_email)".
                    " VALUES(?, ?)", array($groupInfo['name'], $email));
                }
            }
            zput('/request/status', 200);
            return;
        }
        // If we get here there was an error somewhere
        zput('/request/status', 400);
        echo $errorResponse;    
	}
}
?>
