<?php
include "contactutils.php";

class Contact {
	/**
	 * Create the contact information for a person when he is out of the office
	 * @success 200 the contact information for the person with the specified information is created
	 * @error 400 the contact information specified was invalid
	 * @format text/json
	 * @example
	 * {
	 *    "email": "data", 
	 *    "day":("today"| todayAM| todayPM | tomorrow | tommorowAM| tomorrowPM| range), 
	 *    "startdate":"yyyymmdd", 
	 *    "enddate":"yyyymmdd", 
	 *    "reason":"WAH|VAC|PB|OTHER|CLASS|BACK", 
	 *    "alt_phone":"data", 
	 *    "details":"data"
	 * }
	 * 
	 */
	function onCreate() {
		$dateFormat = 'Y-m-d';
	    date_default_timezone_set('America/New_York');
		// Create / replace an absence record for a person
		$absence = json_decode($HTTP_RAW_POST_DATA);
		// Expect {"email": "data", "day":("today"| todayAM| todayPM | tomorrow | tommorowAM| tomorrowPM| range), 
		// "startdate":"yyyymmdd", "enddate":"yyyymmdd", "reason":"WAH|VAC|PB|OTHER|CLASS|BACK", "alt_phone":"data", "details":"data"}

		// preconditions if tod != all then sd = ed;
		$invalid = false;
		global $errormsg;
		$errormsg = "";
		$invalid |= validate_input( $absence, array("email", "day", "reason"));
		if ($absence['day'] == 'range') {
			$invalid |= validate_input($absence, array('startdate', 'enddate'));
		}
		// db updates if email, sd, ed, tod exists - replace
		switch($absence['day']) {
			case 'today':
				$startdate = $enddate = date($dateFormat);
				$tod = 'ALL';
				break;
			case 'todayAM':
				$startdate = $enddate = date($dateFormat);
				$tod = 'AM';
				break;
			case 'todayPM':
				$startdate = $enddate = date($dateFormat);
				$tod = 'PM';
				break;
			case 'tomorrow':
				$startdate = $enddate = date($dateFormat, time() + 86400);
				$tod = 'ALL';
				break; 
			case 'tomorrowAM':
				$startdate = $enddate = date($dateFormat, time() + 86400);
				$tod = 'AM';
				break;
			case 'tomorrowPM':
				$startdate = $enddate = date($dateFormat, time() + 86400);
				$tod = 'PM';
				break;
			case 'range':
				$startdate = $absence['startdate'];
				$enddate = $absence['enddate'];
				$tod = 'ALL';
				break;
			case 'day':
				$startdate = $absence['startdate'];
				$enddate = $absence['startdate'];
				$tod = $absence['tod'];
				break;				
			default:
				$invalid = true;
				$errormsg += "Invalid value for input (day)\n";
				echo "Invalid value for input (day)\n";
				break;
		}

		if ($invalid) {
			zput('/request/status', 400);
			echo $errormsg;
			return;
		}
		// Create a details field.

		$autoDetail = $autoSummary = expand_reason($absence['reason'])." ".expand_dates($startdate, $enddate, $tod);
	 	if (isset($absence['details'])) {
			$autoDetail = $autoDetail.".\n".$absence['details'];
		}
		$dm = data_manager('hallmondb');
		// Delete any old matching absences  
		$result = data_exec($dm, "DELETE FROM absence WHERE email=? AND startdate=? AND enddate=? AND tod=?", array($absence['email'], $startdate, $enddate, $tod));
		// Replace with current this absence
		$result = data_exec($dm, "INSERT INTO absence(email, startdate, enddate, tod, reason, details) VALUES (?, ?, ?, ?, ?, ?)",
			array($absence['email'], $startdate, $enddate, $tod, $absence['reason'], $autoDetail));
	
		$emails = send_notifications($absence['email'], $autoSummary, $autoDetail);
		// Set a Location header with URI to the new record
		if ($result > 0) {
			$locationUri = zget("/request/path") . "/" . $absence["email"];
			zput("/request/headers/out/Location", $locationUri);
			zput("/request/status", 200);
		} else {
			zput("/request/status", 400);
			echo "Failed to add absence - valid data ?";
		}
	}
	
	/**
	 * Retrieve a particular contact for the specified person on
	 * the date provided if it exists, otherwise assume contact information for today.
	 * 
	 * @success 200 returns the list of contact information associated with a person on a particular day
	 * @format application/json
	 * @example 
	 * {
	 *    row from absence table
	 * }
	 */
	function onRetrieve() {
		// Get the contact information for this person
		$email = zget('/request/params/contactId');

		$isdate = zcontains('/request/params/date');
		if (!$isdate) {
			$date = date("Y-m-d");
			//$date = "2007-06-08";	
		} else {
			$date = zget('request/params/date');
		}

		// Get specific status for this person on this date.
		$dm = data_manager('hallmondb');
	
		// Do a left join with absences for this date.
		$sql = "SELECT * FROM absence WHERE email = ? AND DATE(startdate) <= CURRENT_DATE AND DATE(enddate) >= CURRENT_DATE ORDER BY updatestamp DESC,tod";
		$people = data_exec($dm, $sql, array($email));
				
		echo json_encode($people);
	}
}

?>
